import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  "https://gist.githubusercontent.com/ct0571/9bd76a70430e9a2435d5f7ce469d9ccd/raw/7e2e55a4cdd0cd0db6f1b3c1ea100e6ed656adef/Earthquake21.csv"
const width = 910;
const height = 500;
const margin = { top: 20, right: 30, bottom: 50, left: 100 };


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.mag = +d['mag'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;
 

  const yScale = scaleBand()
    .domain(data.map(d => d.locationSource))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.mag)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="coral" />
            <text
              style={{ textAnchor: 'middle' }}
              dy="1.50em"
              y={innerHeight + 5}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy="0.20em"
            y={yScale(tickValue) + yScale.bandwidth()/2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.locationSource}
            x={0}
            y={yScale(d.locationSource)}
            width={xScale(d.mag)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);